SystemOrganization addCategory: #'Seaside-HTML5-Callbacks'!
SystemOrganization addCategory: #'Seaside-HTML5-Tags'!

!WAAbstractTextAreaTag methodsFor: '*seaside-html5' stamp: 'pmm 3/30/2007 11:53'!
pattern: aString
	"no known browser support
	
	For the text, password, email, and url types of the input element, and for the textarea element, the pattern attribute specifies a pattern that the control value must match. 

When specified, the pattern attribute contains a regular expression that the control's value must match before the form may be submitted.

	The regular expression language used for this attribute is the same as that defined in [ECMA262], except that the pattern attribute must match the entire value, not just any subset (somewhat as if it implied a ^(?: at the start of the pattern and a )$ at the end). The pattern must be compiled with the global, ignoreCase, and multiline flags disabled (see ECMA262, sections 15.10.7.2 through 15.10.7.4). If the attribute is omitted then the control has no pattern restriction.
	
	The / character is not special in the pattern attribute. The two attributes pattern='/etc/.+' and pattern='\/etc\/.+' are therefore equivalent. 

	In the case of the email and url types, the pattern attribute specifies a pattern that must be matched in addition to the value matching the generic pattern relevant for the control."
	self attributeAt: 'pattern' put: aString! !

!WAAbstractTextAreaTag methodsFor: '*seaside-html5' stamp: 'pmm 8/1/2010 14:09'!
placeholder: aString
	"The placeholder  attribute represents a short hint (a word or short phrase) intended to aid the user with data entry. A hint could be a sample value or a brief description of the expected format. The attribute, if specified, must have a value that contains no U+000A LINE FEED (LF) or U+000D CARRIAGE RETURN (CR) characters."
	self attributeAt: 'placeholder' put: aString! !

WAAbstractTextAreaTag subclass: #WAColorInputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAColorInputTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
type
	^ 'color'! !

WAAbstractTextAreaTag subclass: #WAEmailInputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAEmailInputTag commentStamp: 'pmm 3/16/2007 13:38' prior: 0!
supported on:
- Opera 9
graceful degeneration to text input

An e-mail address, following the format of the addr-spec  token defined in RFC 2822 section 3.4.1 [RFC2822], but excluding the CFWS  subtoken everywhere, and excluding the FWS subtoken everywhere except in the quoted-string subtoken. UAs could, for example, offer e-mail addresses from the user's address book. (See below for notes on IDN.)!

!WAEmailInputTag methodsFor: 'callbacks' stamp: 'pmm 6/14/2009 13:33'!
callback: aBlock
	self name: (self storeCallback: (WAEmailCallback on: aBlock)).
	self value: self value! !

!WAEmailInputTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
type
	^ 'email'! !

WAAbstractTextAreaTag subclass: #WASearchInputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WASearchInputTag commentStamp: 'pmm 3/16/2007 13:37' prior: 0!
supported on:
- Safari 1.3 and 2.0
not (yet) part of HTML5
graceful degeneration to text input

http://weblogs.mozillazine.org/hyatt/archives/2004_07.html#005890!

!WASearchInputTag methodsFor: 'attributes' stamp: 'pmm 3/16/2007 11:47'!
autosave: aString
	"The autosave attribute allows you to specify an autosave name for your search results in the dropdown. What's cool about the autosave is that it's global, which means that two Web sites could put up a search field with an autosave name of google and then they would share the search results. (Since the actual result values are not accessible to the page there is no privacy violation.)"
	self attributeAt: 'autosave' put: aString! !

!WASearchInputTag methodsFor: 'attributes' stamp: 'pmm 3/16/2007 11:46'!
incremental: aBoolean
	"The incremental attribute can be used to control whether or not the search is performed as you type."
	self attributeAt: 'incremental' put: aBoolean! !

!WASearchInputTag methodsFor: 'events' stamp: 'pmm 3/16/2007 11:44'!
onSearch: aString
	"The search DOM event fires at the precise time the search should be performed and obeys the heuristic for the control, so you don't have to trap key and click events at all. You can use the onsearch attribute on the control to respond when the search happens."

	self attributes at: 'onsearch' append: aString separator: ';'! !

!WASearchInputTag methodsFor: 'attributes' stamp: 'pmm 3/16/2007 11:43'!
results: aNumber
	"The results attribute allows you to specify how many results should be displayed in the dropdown."
	self attributeAt: 'results' put: aNumber! !

!WASearchInputTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
type
	^ 'search'! !

WAAbstractTextAreaTag subclass: #WASteppedTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

WASteppedTag subclass: #WAClosedRangeTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAClosedRangeTag commentStamp: 'pmm 3/16/2007 13:02' prior: 0!
abstract class for all the elments that have a step, min and max attribute!

!WAClosedRangeTag methodsFor: 'attributes' stamp: 'pmm 3/16/2007 13:02'!
max: anInteger
	self attributeAt: 'max' put: anInteger! !

!WAClosedRangeTag methodsFor: 'attributes' stamp: 'pmm 3/16/2007 13:02'!
min: anInteger
	self attributeAt: 'min' put: anInteger! !

WAClosedRangeTag subclass: #WANumberInputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WANumberInputTag commentStamp: 'pmm 3/16/2007 13:38' prior: 0!
supported on:
- Opera 9
graceful degeneration to text input

A numerical value. The step attribute specifies the precision, defaulting to 1.

Numbers must be submitted as a significand followed by an optional exponent. The significand is an optional minus sign (U+002D, "-"), an integer, and optionally a decimal point (U+002E, ".") and an integer representing the fractional part. The exponent is a lowercase literal letter "e", an optional minus sign, and an integer representing the index of a power of ten with which to multiply the significand to get the actual number. Integers are one or more decimal digits. If the exponent part is omitted its index of a power of ten must be assumed to be zero.

For example, negative-root-two, to 32 significant figures, would be -1.4142135623730950488016887242097e0, the radius of the earth given in furlongs, to an arbitrary precision, would be 3.17e4, and the answer to the life, the universe and everything could be any of (amongst others) 42, 0042.000, 42e0, 4.2e1, or 420e-1.

This format is designed to be compatible with scanf(3)'s %f format, ECMAScript's parseFloat, and similar parsers while being easier to parse than some other floating point syntaxes that are also compatible with those parsers.

The strings +0, 0e+0, and +1e+3 are all invalid numbers (the minus sign cannot be replaced by a plus sign for non-negative numbers, it must simply be omitted). Similarly, .42e2 is invalid (there must be at least one digit before the decimal point). UAs must not submit numbers in invalid formats (whatever the user might enter).

The submission format is not intended to be the format seen and used by users. UAs may use whatever format and UI is appropriate for user interaction; the description above is simply the submission format.!

!WANumberInputTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
type
	^ 'number'! !

WAClosedRangeTag subclass: #WARangeInputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WARangeInputTag commentStamp: 'pmm 3/16/2007 13:38' prior: 0!
supported on:
- Safari 2.0 (slider)
graceful degeneration to text input

For this type, step defaults to 1, min defaults to 0, max defaults to 100, and value  defaults to the min value.

Volume controls and brightness controls would be good examples of "range" data controls.!

!WARangeInputTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
type
	^ 'range'! !

WAClosedRangeTag subclass: #WATimeInputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WATimeInputTag commentStamp: 'pmm 3/16/2007 14:05' prior: 0!
supported on:
- Opera 9
graceful degeneration to text input

A time (hour, minute, seconds, fractional seconds) encoded according to ISO 8601 [ISO8601] with no time zone: two digits (0-9) for the hour, a colon (U+003A), two digits for the minute, optionally a colon and two digits for the second, and optionally (if the seconds are present) a period (U+002E) and one or more digits for the fraction of a second. All the numbers must be in base ten and zero-padded if necessary. If the seconds are omitted, they must be assumed to be zero. If the fraction is omitted, it must be assumed to be zero as well. For instance: 23:59:00.00000 or 00:00:05. The step attribute specifies the precision in seconds, defaulting to 60. Times must be greater than or equal to 0 and must be less than 24 hours, in addition to any tighter restrictions placed on the control by the min and max attributes. Note that this type is not an elapsed time data type.

User agents are expected to show an appropriate widget, such as a clock. UAs should make it clear to the user that the time does not carry any time zone information. !

!WATimeInputTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
type
	^ 'time'! !

WASteppedTag subclass: #WADateInputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WADateInputTag commentStamp: 'pmm 3/16/2007 14:05' prior: 0!
supported on:
- Opera 9
graceful degeneration to text input

A date (year, month, day) encoded according to ISO 8601 [ISO8601]: four or more digits (0 to 9) representing the year, a hyphen (U+002D), two digits for the month, a hyphen, and two digits for the day. All the numbers must be in base ten and zero padded if necessary. For instance: 1995-12-31. The step attribute specifies the precision in days, defaulting to 1. User agents are expected to show an appropriate widget, such as a datepicker.!

!WADateInputTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
type
	^ 'date'! !

WASteppedTag subclass: #WADateTimeInputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WADateTimeInputTag commentStamp: 'pmm 3/16/2007 14:05' prior: 0!
supported on:
- Opera 9
graceful degeneration to text input

A date and time (year, month, day, hour, minute, second, fractions of a second) encoded according to ISO 8601 [ISO8601] with the time zone set to UTC: four or more digits (0 to 9) representing the year, a hyphen (U+002D), two digits for the month, a hyphen, two digits for the day, a literal "T", two digits for the hour, a colon (U+003A), two digits for the minute, optionally a colon and two digits for the second, optionally (if the seconds are present) a period (U+002E) and one or more digits for the fraction of a second, and finally a mandatory literal "Z". All the numbers must be in base ten and zero-padded if necessary. If the seconds are omitted, they must be assumed to be zero. If the fraction is omitted, it must be assumed to be zero as well. For instance: 1995-12-31T23:59:59.99Z or, representing the time 10 milliseconds later, 1996-01-01T00:00Z. The step attribute specifies the precision in seconds, defaulting to 60 (one minute).

User agents are expected to show an appropriate widget. UAs may display the time in whatever time zone is appropriate for the user, but should be clear to the user that the time is globally defined, not time-zone dependent. The submitted date and time must be in the UTC time zone.!

!WADateTimeInputTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
type
	^ 'datetime'! !

WASteppedTag subclass: #WADateTimeLocalInputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WADateTimeLocalInputTag commentStamp: 'pmm 3/16/2007 14:05' prior: 0!
supported on:
- Opera 9
graceful degeneration to text input

A date and time (year, month, day, hour, minute, second, fractions of a second) encoded according to ISO 8601 [ISO8601], with no time zone information: four or more digits (0 to 9) representing the year, a hyphen (U+002D), two digits for the month, a hyphen, two digits for the day, a literal "T", two digits for the hour, a colon (U+003A), two digits for the minute, optionally a colon and two digits for the second, and optionally (if the seconds are present) a period (U+002E) and one or more digits for the fraction of a second. All the numbers must be in base ten and zero-padded if necessary. If the seconds are omitted, they must be assumed to be zero. If the fraction is omitted, it must be assumed to be zero as well. For instance: 1995-12-31T23:59:59.99 or, representing the time 10 milliseconds later, 1996-01-01T00:00. The step attribute specifies the precision in seconds, defaulting to 60 (one minute).!

!WADateTimeLocalInputTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
type
	^ 'datetime-local'! !

WASteppedTag subclass: #WAMonthInputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAMonthInputTag commentStamp: 'pmm 3/16/2007 14:05' prior: 0!
supported on:
- Opera 9
graceful degeneration to text input

A date consisting of a year and a month encoded according to ISO 8601 [ISO8601]: four or more digits (0 to 9) representing the year, a hyphen (U+002D), and two digits for the month, zero-padded if necessary. All the numbers must be in base ten. For instance: 1995-12. The step  attribute specifies the precision in months, defaulting to 1. This type is used most frequently for credit card expiry dates.!

!WAMonthInputTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
type
	^ 'month'! !

!WASteppedTag methodsFor: 'attributes' stamp: 'pmm 3/16/2007 13:01'!
step: anInteger
	self attributeAt: 'step' put: anInteger! !

WASteppedTag subclass: #WAWeekInputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAWeekInputTag commentStamp: 'pmm 3/16/2007 14:05' prior: 0!
supported on:
- Opera 9
graceful degeneration to text input

A date consisting of a year and a week number encoded according to ISO 8601 [ISO8601]: four or more digits (0 to 9) representing the year, a hyphen (U+002D), a literal "W", and two digits for the week, zero-padded if necessary. All the numbers must be in base ten. The week number must be a number greater than or equal to 01. Week 01 of a given year is the week containing the 4th of January; weeks start on Monday. For instance: 2005-W52 is the week that ends on Sunday the first of January, 2006. The step attribute specifies the precision in weeks, defaulting to 1. This type is used most frequently for dates in European industry.!

!WAWeekInputTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
type
	^ 'week'! !

WAAbstractTextAreaTag subclass: #WATelephoneInputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WATelephoneInputTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
type
	^ 'telephone'! !

WAAbstractTextAreaTag subclass: #WAUrlInputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAUrlInputTag commentStamp: 'pmm 3/16/2007 13:37' prior: 0!
supported on:
- Opera 9
graceful degeneration to text input

An IRI, as defined by [RFC3987] (the IRI token, defined in RFC 3987 section 2.2). UAs could, for example, offer the user URIs from his bookmarks. (See below for notes on IDN.) The value is called url (as opposed to iri or uri) for consistency with CSS syntax and because it is generally felt authors are more familiar with the term "URL" than the other, more technically correct terms.!

!WAUrlInputTag methodsFor: 'callbacks' stamp: 'pmm 6/14/2009 13:38'!
callback: aBlock
	self name: (self storeCallback: (WAUrlCallback on: aBlock)).
	self value: self value! !

!WAUrlInputTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
type
	^ 'url'! !

WACollectionTag subclass: #WADatalistTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WADatalistTag commentStamp: 'pmm 7/29/2007 00:44' prior: 0!
datalist together with the a new list attribute for input is used to make comboboxes:

<input list=browsers>
<datalist id=browsers>
 <option value="Safari">
 <option value="Internet Explorer">
 <option value="Opera">
 <option value="Firefox">
</datalist>

!

!WADatalistTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
tag
	^ 'datalist'! !

!WAOrderedListTag methodsFor: '*seaside-html5' stamp: 'pmm 2/8/2011 21:59'!
reversed: aBoolean
	"The reversed attribute is a boolean attribute. If present, it indicates that the list is a descending list (..., 3, 2, 1). If the attribute is omitted, the list is an ascending list (1, 2, 3, ...)."
	self attributes at: 'reversed' put: aBoolean! !

!WAOrderedListTag methodsFor: '*seaside-html5' stamp: 'pmm 2/8/2011 22:00'!
start: anInteger
	"The start attribute, if present, must be a valid integer giving the ordinal value of the first list item.

If the start attribute is present, user agents must parse it as an integer, in order to determine the attribute's value. The default value, used if the attribute is missing or if the value cannot be converted to a number according to the referenced algorithm, is 1 if the element has no reversed attribute, and is the number of child li elements otherwise.

The first item in the list has the ordinal value given by the ol element's start attribute, unless that li element has a value attribute with a value that can be successfully parsed, in which case it has the ordinal value given by that value attribute.

Each subsequent item in the list has the ordinal value given by its value attribute, if it has one, or, if it doesn't, the ordinal value of the previous item, plus one if the reversed is absent, or minus one if it is present.
"
	self attributes at: 'start' put: anInteger! !

!WAOrderedListTag methodsFor: '*seaside-html5' stamp: 'pmm 2/12/2011 10:03'!
type: aString
	"The type attribute can be used to specify the kind of marker to use in the list, in the cases where that matters (e.g. because items are to be referened by their number/letter). The attribute, if specified, must have a value that is a case-sensitive match for one of the characters given in the first cell of one of the rows of the following table. The type attribute represents the state given in the cell in the second column of the row whose first cell matches the attribute's value; if none of the cells match, or if the attribute is omitted, then the attribute represents the decimal state.
Keyword 	State 	Description 	Examples for values 1-3 and 3999-4001
1 (U+0031) 	decimal 	Decimal numbers 	1. 	2. 	3. 	... 	3999. 	4000. 	4001. 	...
a (U+0061) 	lower-alpha 	Lowercase latin alphabet 	a. 	b. 	c. 	... 	ewu. 	ewv. 	eww. 	...
A (U+0041) 	upper-alpha 	Uppercase latin alphabet 	A. 	B. 	C. 	... 	EWU. 	EWV. 	EWW. 	...
i (U+0069) 	lower-roman 	Lowercase roman numerals 	i. 	ii. 	iii. 	... 	mmmcmxcix. 	iv. 	ivi. 	...
I (U+0049) 	upper-roman 	Uppercase roman numerals 	I. 	II. 	III. 	... 	MMMCMXCIX. 	IV. 	IVI. 	...

User agents should render the items of the list in a manner consistent with the state of the type attribute of the ol element. Numbers less than or equal to zero should always use the decimal system regardless of the type attribute."
	self attributes at: 'type' put: aString! !

!GRPackage classSide methodsFor: '*seaside-html5' stamp: 'lr 2/17/2010 15:12'!
seasideHTML5
	^ self new
		name: 'Seaside-HTML5';
		description: 'Support for HTML 5 tags.';
		addDependency: 'Seaside-Canvas';
		url: #seasideUrl;
		yourself! !

!WASelectTag methodsFor: '*seaside-html5' stamp: 'pmm 8/7/2007 18:45'!
listId: aString
	"aString is the id of a datalist"
	self attributeAt: 'list' put: aString! !

WAValueCallback subclass: #WAEmailCallback
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Callbacks'!

!WAEmailCallback commentStamp: 'pmm 6/14/2009 13:29' prior: 0!
A WAEmailCallback is a callback for email input fields.
!

!WAEmailCallback methodsFor: 'converting' stamp: 'lr 7/25/2011 20:00'!
valueForField: anObject
	^ anObject isEmptyOrNil
		ifTrue: [ nil ]
		ifFalse: [ WAEmailAddress address: anObject ]! !

WAValueCallback subclass: #WAUrlCallback
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Callbacks'!

!WAUrlCallback commentStamp: 'pmm 6/14/2009 13:29' prior: 0!
A WAEmailCallback is a callback for url input fields.!

!WAUrlCallback methodsFor: 'converting' stamp: 'lr 7/25/2011 20:13'!
valueForField: anObject
	^ anObject isEmptyOrNil
		ifTrue: [ nil ]
		ifFalse: [ WAUrl absolute: anObject ]! !

!WALinkElement methodsFor: '*seaside-html5' stamp: 'pmm 3/31/2007 00:56'!
beAuthor
	"Gives a link to the current document's author."
	self relationship: 'author'! !

!WAMetaElement methodsFor: '*seaside-html5' stamp: 'pmm 2/8/2011 22:05'!
charset: aString
	"The charset attribute specifies the character encoding used by the document. This is a character encoding declaration. If the attribute is present in an XML document, its value must be an ASCII case-insensitive match for the string 'UTF-8' (and the document is therefore forced to use UTF-8 as its encoding).

The charset attribute on the meta element has no effect in XML documents, and is only allowed in order to facilitate migration to and from XHTML.

There must not be more than one meta element with a charset attribute per document."
	
	self attributes at: 'charset' put: aString! !

!WAAnchorTag methodsFor: '*seaside-html5' stamp: 'pmm 2/8/2011 21:25'!
media: aString
	"This attribute specifies the intended destination medium for style information. It may be a single media descriptor or a comma-separated list. The default value for this attribute is 'screen'."
	self attributeAt: 'media' put: aString! !

WATagBrush subclass: #WACanvasTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WACanvasTag commentStamp: 'pmm 3/16/2007 11:52' prior: 0!
supported on:
- Firefox 1.5
- Safari 2
- Opera 9

http://www.whatwg.org/specs/web-apps/current-work/#the-canvas
http://developer.mozilla.org/en/docs/Canvas_tutorial!

!WACanvasTag methodsFor: 'attributes' stamp: 'lr 5/18/2006 08:52'!
extent: aPoint
	self width: aPoint x; height: aPoint y! !

!WACanvasTag methodsFor: 'attributes' stamp: 'jf 9/30/2009 01:10'!
height: aNumber 
	self 
		attributeAt: 'height'
		put: aNumber greaseString! !

!WACanvasTag methodsFor: 'accessing' stamp: 'lr 5/18/2006 08:50'!
tag
	^ 'canvas'! !

!WACanvasTag methodsFor: 'attributes' stamp: 'jf 9/30/2009 01:10'!
width: aNumber 
	self 
		attributeAt: 'width'
		put: aNumber greaseString! !

WATagBrush subclass: #WACommandTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WACommandTag commentStamp: 'pmm 8/8/2007 22:00' prior: 0!
The command element represents a command that the user can invoke.!

!WACommandTag methodsFor: 'attributes' stamp: 'pmm 8/8/2007 22:03'!
beCheckbox
	self type: 'checkbox'! !

!WACommandTag methodsFor: 'attributes' stamp: 'pmm 8/8/2007 22:06'!
beChecked
	self checked: true! !

!WACommandTag methodsFor: 'attributes' stamp: 'pmm 8/8/2007 22:03'!
beCommand
	self type: 'command'! !

!WACommandTag methodsFor: 'attributes' stamp: 'pmm 8/8/2007 22:06'!
beDisabled
	self disabled: true! !

!WACommandTag methodsFor: 'attributes' stamp: 'pmm 8/8/2007 22:06'!
beHidden
	self hidden: true! !

!WACommandTag methodsFor: 'attributes' stamp: 'pmm 8/8/2007 22:03'!
beRadio
	self type: 'radio'! !

!WACommandTag methodsFor: 'attributes' stamp: 'pmm 8/8/2007 22:05'!
checked: aBoolean
	"The checked attribute is a boolean attribute that, if present, indicates that the command is selected."
	self attributeAt: 'checked' put: aBoolean! !

!WACommandTag methodsFor: 'attributes' stamp: 'pmm 8/8/2007 22:05'!
disabled: aBoolean
	"The disabled attribute is a boolean attribute that, if present, indicates that the command is not available in the current state."
	self attributeAt: 'disabled' put: aBoolean! !

!WACommandTag methodsFor: 'attributes' stamp: 'pmm 8/8/2007 22:05'!
hidden: aBoolean
	"The hidden  attribute is a boolean attribute that, if present, indicates that the command is not relevant and is to be hidden."
	self attributeAt: 'hidden' put: aBoolean! !

!WACommandTag methodsFor: 'attributes' stamp: 'pmm 8/8/2007 22:04'!
icon: aString
	"The icon  attribute gives a picture that represents the command. If the attribute is specified, the attribute's value must contain a URI (or IRI)."
	self attributeAt: 'icon' put: aString! !

!WACommandTag methodsFor: 'attributes' stamp: 'pmm 8/8/2007 22:04'!
label: aString
	"The label  attribute gives the name of the command, as shown to the user."
	self attributeAt: 'label' put: aString! !

!WACommandTag methodsFor: 'accessing' stamp: 'pmm 8/8/2007 22:01'!
tag
	^ 'command'! !

!WACommandTag methodsFor: 'attributes' stamp: 'pmm 8/8/2007 22:02'!
type: aString
	"The type  attribute indicates the kind of command: either a normal command with an associated action, or a state or option that can be toggled, or a selection of one item from a list of items.

The attribute's value must be either 'command', 'checkbox', or 'radio', denoting each of these three types of commands respectively. The attribute may also be omitted if the element is to represent the first of these types, a simple command. "
	self attributeAt: 'type' put: aString! !

WATagBrush subclass: #WADetailsTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WADetailsTag commentStamp: 'pmm 7/29/2007 00:33' prior: 0!
The details element represents additional information or controls which the user can obtain on demand.

The first element child of a details element, if it is a legend element, represents the summary of the details.

If the first element is not a legend element, the UA should provide its own legend (e.g. "Details"). !

!WADetailsTag methodsFor: 'attributes' stamp: 'pmm 8/8/2007 22:09'!
open: aBoolean
	"The open  content attribute is a boolean attribute. If present, it indicates that the details should be shown to the user. If the attribute is absent, the details should not be shown.

	If the attribute is removed, then the details should be hidden. If the attribute is added, the details should be shown."
	self attributeAt: 'open' put: aBoolean! !

!WADetailsTag methodsFor: 'accessing' stamp: 'pmm 8/8/2007 22:09'!
tag
	^ 'details'! !

WATagBrush subclass: #WAEmbedTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAEmbedTag methodsFor: 'attributes' stamp: 'as 2/1/2011 16:40'!
height: anInteger
	self attributeAt: 'height' put: anInteger! !

!WAEmbedTag methodsFor: 'accessing' stamp: 'as 2/1/2011 16:37'!
tag
	^ 'embed'! !

!WAEmbedTag methodsFor: 'attributes' stamp: 'as 2/1/2011 17:00'!
type: aMimeType
	self attributeAt: 'type' put: aMimeType! !

!WAEmbedTag methodsFor: 'attributes' stamp: 'pmm 2/2/2011 19:43'!
url: aString
	"The src attribute gives the address of the resource being embedded."
	self attributeAt: 'src' put: aString! !

!WAEmbedTag methodsFor: 'attributes' stamp: 'as 2/1/2011 16:40'!
width: anInteger
	self attributeAt: 'width' put: anInteger! !

WATagBrush subclass: #WAEventSourceTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAEventSourceTag commentStamp: 'pmm 7/29/2007 00:49' prior: 0!
The event-source element represents a target for events generated by a remote server.

The src attribute, if specified, must give a URI (or IRI) pointing to a resource that uses the application/x-dom-event-stream format.

When the element is inserted into the document, if it has the src attribute specified, the user agent must act as if the addEventSource() method on the event-source element had been invoked with the URI resulting from resolving the src attribute's value to an absolute URI.

While the element is in a document, if its src attribute is mutated, the user agent must act as if first the removeEventSource() method on the event-source element had been invoked with the URI resulting from resolving the old value of the attribute to an absolute URI, and then as if the addEventSource() method on the element had been invoked with the URI resulting from resolving the new value of the src attribute to an absolute URI.

When the element is removed from the document, if it has the src attribute specified, or, when the src attribute is about to be removed, the user agent must act as if the removeEventSource() method on the event-source element had been invoked with the URI resulting from resolving the src attribute's value to an absolute URI.

There can be more than one event-source element per document, but authors should take care to avoid opening multiple connections to the same server as HTTP recommends a limit to the number of simultaneous connections that a user agent can open per server.

The src DOM attribute must reflect the content attribute of the same name. !

!WAEventSourceTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
tag
	^ 'event-source'! !

!WAEventSourceTag methodsFor: 'attributes' stamp: 'pmm 7/29/2007 00:49'!
url: aString
	"The src  attribute, if specified, must give a URI (or IRI) pointing to a resource that uses the application/x-dom-event-stream format."
	self attributeAt: 'src' put: aString! !

WATagBrush subclass: #WAKeyGeneratorTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAKeyGeneratorTag commentStamp: 'pmm 11/11/2008 22:49' prior: 0!
A WAKeygenTag is allows the user agent to generate a secure key and submits the public key.

Supported by:
    * Netscape 3, 4, 6, 7
    * Mozilla 1
    * Firefox 1
    * Opera 3, 4, 5, 6, 7, 8
    * Safari 1 

=== Links for more info ===
http://lists.whatwg.org/pipermail/whatwg-whatwg.org/attachments/20080714/07ea5534/attachment.txt
http://wp.netscape.com/eng/security/comm4-keygen.html
http://wp.netscape.com/eng/security/ca-interface.html
http://webdesign.about.com/od/htmltags/p/bltags_keygen.htm
http://eskimonorth.com/~bloo/indexdot/html/tagpages/k/keygen.htm
http://web.archive.org/web/20040710102131/devedge.netscape.com/library/manuals/1998/htmlguide/
http://64.233.183.104/search?q=cache:TExfCslqOcwJ:www.html4newbies.com/Keygen.php
http://www.di.unito.it/~rabser/ssleay/x509_netscape.html
http://msdn.microsoft.com/en-us/library/cc214558.aspx - Something that may look like the MS version of the keygen attribute
!

!WAKeyGeneratorTag methodsFor: 'callbacks' stamp: 'MAD 2/20/2009 16:13'!
callback: aBlock
	self name: (self storeCallback: (WAValueCallback on: aBlock))! !

!WAKeyGeneratorTag methodsFor: 'attributes' stamp: 'pmm 11/11/2008 22:52'!
challenge: aString
	"Specifies the challenge string to be packaged with the public key for use in verification of the form submission. If no challenge string is provided, then it is encoded as an 'IA5STRING' of length zero. "
	self attributeAt: 'challenge' put: aString! !

!WAKeyGeneratorTag methodsFor: 'testing' stamp: 'lr 7/25/2011 20:11'!
isClosed
	^ true! !

!WAKeyGeneratorTag methodsFor: 'attributes' stamp: 'pmm 11/11/2008 22:53'!
keyType: aString
	"This attribute specifies the type of encryption security method to use to verify the receiver. 
    Values: 'RSA' (default) or 'DSA'"
	self attributeAt: 'keytype' put: aString! !

!WAKeyGeneratorTag methodsFor: 'attributes' stamp: 'pmm 11/11/2008 23:10'!
name: aString
	"The same as WAFormInputTag >> #name:"
	self attributeAt: 'name' put: aString! !

!WAKeyGeneratorTag methodsFor: 'attributes' stamp: 'pmm 11/11/2008 22:55'!
pqg: aString
	"This attribute appears to be a security string to be sent and verified."
	self attributeAt: 'pqg' put: aString! !

!WAKeyGeneratorTag methodsFor: 'accessing' stamp: 'pmm 11/11/2008 23:05'!
tag
	^ 'keygen'! !

WATagBrush subclass: #WAMediaElementTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAMediaElementTag commentStamp: 'as 2/8/2011 14:42' prior: 0!
WAMediaElementTag is an abstract class for all the media elements providing common media attributes.
See: http://www.w3.org/TR/html5/video.html#media-element!

WAMediaElementTag subclass: #WAAudioTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAAudioTag commentStamp: 'pmm 3/28/2007 22:54' prior: 0!
no known browser support, might require an open codec like Ogg Vorbis, might first appear in Opera and Mozilla

An audio element represents a sound or audio stream.

Content may be provided inside the audio element so that older Web browsers, which do not support audio, can display text to the user informing them of how to access the audio contents. User agents should not show this fallback content to the user. !

!WAAudioTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
tag
	^ 'audio'! !

!WAMediaElementTag methodsFor: 'attributes' stamp: 'as 2/8/2011 14:36'!
autoplay: aBoolean
	"The autoplay attribute is a boolean attribute. When present, the user agent (as described in the algorithm described herein) will automatically begin playback of the media resource as soon as it can do so without stopping."
	self attributeAt: 'autoplay' put: aBoolean.! !

!WAMediaElementTag methodsFor: 'attributes' stamp: 'as 2/8/2011 14:37'!
controls: aBoolean
	"The controls attribute is a boolean attribute. If present, it indicates that the author has not provided a scripted controller and would like the user agent to provide its own set of controls."
	self attributeAt: 'controls' put: aBoolean.! !

!WAMediaElementTag methodsFor: 'attributes' stamp: 'as 2/8/2011 14:37'!
loop: aBoolean
	"The loop attribute is a boolean attribute that, if specified, indicates that the media element is to seek back to the start of the media resource upon reaching the end."
	self attributeAt: 'loop' put: aBoolean.! !

!WAMediaElementTag methodsFor: 'attributes' stamp: 'as 2/8/2011 14:33'!
preload: aString
	"The preload attribute is intended to provide a hint to the user agent about what the author thinks will lead to the best user experience.
	See: http://www.w3.org/TR/html5/video.html#attr-media-preload
	
	The preload attribute can have one of three values: 'none', 'metadata', 'auto'.
	Providing an empty string defaults the value of the attribute to be 'auto'."
	self attributeAt: 'preload' put: aString.! !

!WAMediaElementTag methodsFor: 'attributes' stamp: 'as 2/8/2011 14:26'!
url: aString
	self attributeAt: 'src' put: aString! !

WAMediaElementTag subclass: #WAVideoTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAVideoTag commentStamp: 'pmm 4/4/2007 03:01' prior: 0!
Supported only on experimental Opera
http://people.opera.com/howcome/2007/video/

A video element represents a video or movie, with an alternate representation given by its contents.

http://www.whatwg.org/specs/web-apps/current-work/#video
http://lists.whatwg.org/pipermail/whatwg-whatwg.org/attachments/20070228/6a0cdddc/attachment.txt!

!WAVideoTag methodsFor: 'attributes' stamp: 'pmm 3/18/2007 12:57'!
height: anInteger
	"The videoHeight  DOM attribute must return the native height of the video in CSS pixels. In the absence of resolution information, user agents may assume that one pixel in the video corresponds to one CSS pixel."
	self attributeAt: 'height' put: anInteger! !

!WAVideoTag methodsFor: 'attributes' stamp: 'as 2/8/2011 14:35'!
poster: aString
	"The poster attribute gives the address of an image file that the user agent can show while no video data is available. The attribute, if present, must contain a valid non-empty URL potentially surrounded by spaces."
	self attributeAt: 'poster' put: aString.! !

!WAVideoTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
tag
	^ 'video'! !

!WAVideoTag methodsFor: 'attributes' stamp: 'pmm 3/18/2007 12:57'!
width: anInteger
	"The videoWidth DOM attribute must return the native width of the video in CSS pixels. In the absence of resolution information, user agents may assume that one pixel in the video corresponds to one CSS pixel."
	self attributeAt: 'width' put: anInteger! !

WATagBrush subclass: #WAMenuTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAMenuTag commentStamp: 'pmm 3/31/2007 01:10' prior: 0!
no known browser support

The menu element represents a list of commands.

The type attribute indicates the kind of menu. It must have either the value popup (to declare a context menu) or the value toolbar (to define a tool bar). The attribute may also be omitted, to indicate that the element is merely a list of commands that is neither declaring a context menu nor defining a tool bar.

If a menu element has a type attribute with the value popup, then it represents the commands of a context menu, and the user can only interact with the commands if that context menu is activated.

If a menu element has a type attribute with the value toolbar, then it represents a list of active commands that the user can immediately interact with.

Otherwise, if a menu element has no type attribute, or if has a type attribute with a value other than popup or toolbar, then it either represents an unordered list of items (each represented by an li element), each of which represents a command that the user may perform or activate, or, if the element has no li element children, a paragraph describing available commands.

The label attribute gives the label of the menu. It is used by user agents to display nested menus in the UI. For example, a context menu containing another menu would use the nested menu's label attribute for the submenu's menu label.

The autosubmit attribute is a boolean attribute that, if present, indicates that selections made to form controls in this menu are to result in the control's form being immediately submitted. !

!WAMenuTag methodsFor: 'attributes' stamp: 'pmm 3/31/2007 01:12'!
autosubmit
	"The autosubmit attribute is a boolean attribute that, if present, indicates that selections made to form controls in this menu are to result in the control's form being immediately submitted."
	self attributeAt: 'autosubmit' put: true! !

!WAMenuTag methodsFor: 'type' stamp: 'pmm 3/31/2007 01:11'!
bePopup
	self type: 'popup'! !

!WAMenuTag methodsFor: 'type' stamp: 'pmm 3/31/2007 01:12'!
beToolbar
	self type: 'toolbar'! !

!WAMenuTag methodsFor: 'attributes' stamp: 'pmm 3/31/2007 01:12'!
label: aString
	"The label  attribute gives the label of the menu. It is used by user agents to display nested menus in the UI. For example, a context menu containing another menu would use the nested menu's label attribute for the submenu's menu label."
	self attributeAt: 'label' put: aString! !

!WAMenuTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
tag
	^ 'menu'! !

!WAMenuTag methodsFor: 'attributes' stamp: 'pmm 3/31/2007 01:11'!
type: aString
	"The type  attribute indicates the kind of menu. It must have either the value popup (to declare a context menu) or the value toolbar (to define a tool bar). The attribute may also be omitted, to indicate that the element is merely a list of commands that is neither declaring a context menu nor defining a tool bar."
	self attributeAt: 'type' put: aString! !

WATagBrush subclass: #WAMeterTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAMeterTag commentStamp: 'pmm 3/28/2007 22:34' prior: 0!
No known browser support.

The meter element represents a scalar measurement within a known range, or a fractional value; for example disk usage, the relevance of a query result, or the fraction of a voting population to have selected a particular candidate.

This is also known as a gauge.

The meter element should not be used to indicate progress (as in a progress bar). For that role, HTML provides a separate progress element.

There are six attributes that determine the semantics of the gauge represented by the element.

The min attribute specifies the lower bound of the range, and the max attribute specifies the upper bound. The value attribute specifies the value to have the gauge indicate as the "measured" value.

The other three attributes can be used to segment the gauge's range into "low", "medium", and "high" parts, and to indicate which part of the gauge is the "optimum" part. The low attribute specifies the range that is considered to be the "low" part, and the high attribute specifies the range that is considered to be the "high" part. The optimum attribute gives the position that is "optimum"; if that is higher than the "high" value then this indicates that the higher the value, the better; if it's lower than the "low" mark then it indicates that lower values are better, and naturally if it is in between then it indicates that neither high nor low values are good.

The value, min, low, high, max, and optimum attributes are all optional. When present, they must have values that are valid floating point numbers.

The following examples all represent a measurement of three quarters (of the maximum of whatever is being measured):

<meter>75%</meter>
<meter>750\u2030</meter>
<meter>3/4</meter>
<meter>6 blocks used (out of 8 total)</meter>
<meter>max: 100; current: 75</meter>
<meter><object data="graph75.png">0.75</object></meter>
<meter min="0" max="100" value="75"></meter>

!

!WAMeterTag methodsFor: 'attributes' stamp: 'pmm 3/28/2007 22:35'!
high: anInteger
	"The high attribute specifies the range that is considered to be the 'high' part."
	self attributeAt: 'high' put: anInteger! !

!WAMeterTag methodsFor: 'attributes' stamp: 'pmm 3/28/2007 22:34'!
low: anInteger
	"The low attribute specifies the range that is considered to be the 'low' part."
	self attributeAt: 'low' put: anInteger! !

!WAMeterTag methodsFor: 'attributes' stamp: 'pmm 3/28/2007 22:31'!
max: anInteger
	"The the max attribute specifies the upper bound of the range."
	self attributeAt: 'max' put: anInteger! !

!WAMeterTag methodsFor: 'attributes' stamp: 'pmm 3/28/2007 22:31'!
min: anInteger
	"The min attribute specifies the lower bound of the range."
	self attributeAt: 'min' put: anInteger! !

!WAMeterTag methodsFor: 'attributes' stamp: 'pmm 3/28/2007 22:35'!
optimum: anInteger
	"The optimum attribute gives the position that is 'optimum'; if that is higher than the 'high' value then this indicates that the higher the value, the better; if it's lower than the 'low' mark then it indicates that lower values are better, and naturally if it is in between then it indicates that neither high nor low values are good."
	self attributeAt: 'optimum' put: anInteger! !

!WAMeterTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
tag
	^ 'meter'! !

!WAMeterTag methodsFor: 'attributes' stamp: 'pmm 3/28/2007 22:32'!
value: anInteger
	"The value  attribute specifies the value to have the gauge indicate as the 'measured' value."
	self attributeAt: 'value' put: anInteger! !

WATagBrush subclass: #WAOptionalBreakTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAOptionalBreakTag methodsFor: 'testing' stamp: 'as 1/30/2011 04:48'!
isClosed
	^ true! !

!WAOptionalBreakTag methodsFor: 'accessing' stamp: 'as 1/30/2011 04:48'!
tag
	^ 'wbr'! !

WATagBrush subclass: #WAOutputTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAOutputTag methodsFor: 'attributes' stamp: 'as 2/1/2011 17:23'!
for: aString
	"The for content attribute allows an explicit relationship to be made between the result of a calculation and the elements that represent the values that went into the calculation or that otherwise influenced the calculation. The for attribute, if specified, must contain a string consisting of an unordered set of unique space-separated tokens that are case-sensitive, each of which must have the value of an ID of an element in the same Document."
	self attributeAt: 'for' put: aString! !

!WAOutputTag methodsFor: 'attributes' stamp: 'as 2/1/2011 17:24'!
form: aString
	"The form attribute is used to explicitly associate the output element with its form owner."
	self attributeAt: 'form' put: aString! !

!WAOutputTag methodsFor: 'attributes' stamp: 'as 2/1/2011 17:25'!
name: aString
	self attributeAt: 'name' put: aString! !

!WAOutputTag methodsFor: 'accessing' stamp: 'as 2/1/2011 17:22'!
tag
	^ 'output'! !

WATagBrush subclass: #WAProgressTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WAProgressTag commentStamp: 'pmm 3/28/2007 22:40' prior: 0!
No known browser support.

The progress element represents the completion progress of a task. The progress is either indeterminate, indicating that progress is being made but that it is not clear how much more work remains to be done before the task is complete (e.g. because the task is waiting for a remote host to respond), or the progress is a number in the range zero to a maximum, giving the fraction of work that has so far been completed.

There are two attributes that determine the current task completion represented by the element.

The value attribute specifies how much of the task has been completed, and the max attribute specifies how much work the task requires in total. The units are arbitrary and not specified.

Instead of using the attributes, authors are recommended to simply include the current value and the maximum value inline as text inside the element.

!

!WAProgressTag methodsFor: 'attributes' stamp: 'pmm 3/28/2007 22:41'!
max: anInteger
	"The max attribute specifies how much work the task requires in total"
	self attributeAt: 'max' put: anInteger! !

!WAProgressTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
tag
	^ 'progress'! !

!WAProgressTag methodsFor: 'attributes' stamp: 'pmm 3/28/2007 22:41'!
value: anInteger
	"The value  attribute specifies how much of the task has been completed."
	self attributeAt: 'value' put: anInteger! !

WATagBrush subclass: #WARubyTextTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WARubyTextTag commentStamp: 'obi 4/2/2008 22:50' prior: 0!
This element works with the <ruby> element. 
The text following <rt> appears as a note to the base text displayed by the 
<ruby> element.!

!WARubyTextTag methodsFor: 'attributes' stamp: 'lr 3/24/2008 13:01'!
span: anInteger 
	self attributes 
		at: 'rbspan'
		put: anInteger! !

!WARubyTextTag methodsFor: 'accessing' stamp: 'pmm 9/18/2006 19:00'!
tag
	^ 'rt'! !

WATagBrush subclass: #WASourceTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WASourceTag commentStamp: 'pmm 7/29/2007 10:46' prior: 0!
The source element allows authors to specify multiple media resources for media elements.

The source attribute must be present. Either the type  attribute, the media attribute or both, must be specified, unless this is the last source element child of the parent element.!

!WASourceTag methodsFor: 'attributes' stamp: 'pmm 7/29/2007 10:50'!
media: aString
	"The media  attribute gives the intended media type of the media resource, to help the user agent determine if this media resource is useful to the user before downloading it. Its value must be a valid media query. [MQ]"
	self attributeAt: 'media' put: aString! !

!WASourceTag methodsFor: 'accessing' stamp: 'pmm 7/29/2007 10:46'!
tag
	^ 'source'! !

!WASourceTag methodsFor: 'attributes' stamp: 'pmm 7/29/2007 10:49'!
type: aString
	"The type  attribute gives the type of the media resource, to help the user agent determine if it can play this media resource before downloading it. Its value must be a MIME type. The codec parameter may be specified and might be necessary to specify exactly how the resource is encoded.
	http://www.faqs.org/rfcs/rfc2046.html
	http://www.faqs.org/rfcs/rfc4281.html"
	self attributeAt: 'type' put: aString! !

!WASourceTag methodsFor: 'attributes' stamp: 'pmm 7/29/2007 10:47'!
url: aString
	"The src attribute gives the address of the media resource. The value must be a URI (or IRI). This attribute must be present."
	self attributeAt: 'src' put: aString! !

!WATagBrush methodsFor: '*seaside-html5' stamp: 'pmm 3/16/2007 12:05'!
autofocus
	"supported on:
	- Opera 9"
	self attributeAt: 'autofocus' put: true! !

!WATagBrush methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 00:30'!
irrelevant
	"All elements may have the irrelevant content attribute set. The irrelevant  attribute is a boolean attribute. When specified on an element, it indicates that the element is not yet, or is no longer, relevant. User agents should not render elements that have the irrelevant  attribute specified."
	self attributeAt: 'irrelevant' put: true! !

!WATagBrush methodsFor: '*seaside-html5' stamp: 'lr 2/21/2010 20:00'!
onInput: anObject
	"Any element that accepts an onchange attribute to handle change events shall also accept an oninput  attribute to handle input events, except the output element (for which it would make no sense)."

	self document scriptGenerator
		event: 'input'
		do: anObject
		on: self! !

!WATagBrush methodsFor: '*seaside-html5' stamp: 'pmm 3/16/2007 12:07'!
required
	"supported on:
	- Opera 9"
	self attributeAt: 'required' put: true! !

WATagBrush subclass: #WATimeTag
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-HTML5-Tags'!

!WATimeTag commentStamp: 'pmm 4/20/2007 01:25' prior: 0!
http://www.whatwg.org/specs/web-apps/current-work/#the-time
not known browser support

The time element represents a date and/or a time.

The datetime attribute, if present, must contain a date or time string that identifies the date or time being specified.

If the datetime attribute is not present, then the date or time must be specified in the content of the element, such that parsing the element's textContent according to the rules for parsing date or time strings in content successfully extracts a date or time. 

see RFC 3339:
http://www.ietf.org/rfc/rfc3339.txt!

!WATimeTag methodsFor: 'attributes' stamp: 'pmm 4/20/2007 01:21'!
datetime: anObject
	"The datetime attribute, if present, must contain a date or time string that identifies the date or time being specified."
	self attributeAt: 'datetime' put: anObject! !

!WATimeTag methodsFor: 'accessing' stamp: 'lr 7/25/2011 20:11'!
tag
	^ 'time'! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:54'!
article
	"The article element represents a section of a page that consists of a composition that forms an independent part of a document, page, or site. This could be a forum post, a magazine or newspaper article, a Web log entry, a user-submitted comment, or any other independent item of content.

	An article element is 'independent' in that its contents could stand alone, for example in syndication. However, the element is still associated with its ancestors; for instance, contact information that applies to a parent body element still covers the article as well.

	When article elements are nested, the inner article elements represent articles that are in principle related to the contents of the outer article. For instance, a Web log entry on a site that accepts user-submitted comments could represent the comments as article elements nested within the article element for the Web log entry.

	Author information associated with an article element (q.v. the address element) does not apply to nested article elements.

	Each article element potentially has a heading."
	^ self tag: 'article'! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:54'!
article: aBlock
	self article with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:42'!
aside
	"The aside element represents a section of a page that consists of content that is tangentially related to the content around the aside element, and which could be considered separate from that content. Such sections are often represented as sidebars in printed typography.

	When used as an inline-level content container, the element represents a paragraph.

	Each aside element potentially has a heading. "
	^ self tag: 'aside'! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:42'!
aside: aBlock
	self aside with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'as 2/1/2011 18:11'!
audio
	"An audio element represents a sound or audio stream."
	^ self brush: WAAudioTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'as 1/30/2011 05:41'!
audio: aBlock
	self audio with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 2/2/2011 19:42'!
bidirectional
	"The bdi element represents a span of text that is to be isolated from its surroundings for the purposes of bidirectional text formatting."
	^ self tag: 'bdi'! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 2/2/2011 19:43'!
bidirectional: aBlock
	self bidirectional with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'lr 5/18/2006 08:55'!
canvas
	^ self brush: WACanvasTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'mb 11/30/2006 16:29'!
canvas: aBlock
	self canvas with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'as 2/6/2011 21:58'!
colorInput
	^ self brush: WAColorInputTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 8/8/2007 22:08'!
command
	^ self brush: WACommandTag new	! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 8/8/2007 22:08'!
command: aBlock
	self command with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'as 2/6/2011 21:59'!
datalist
	^ self brush: WADatalistTag new	! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'as 2/6/2011 21:59'!
datalist: aBlock
	self datalist with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'as 2/6/2011 21:59'!
dateInput5
	^ self brush: WADateInputTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'as 2/6/2011 21:59'!
dateTimeInput
	^ self brush: WADateTimeInputTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'as 2/6/2011 21:59'!
dateTimeLocalInput
	^ self brush: WADateTimeLocalInputTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:40'!
details
	^ self brush: WADetailsTag new	! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:40'!
details: aBlock
	self details with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'as 2/6/2011 22:00'!
emailInput
	^ self brush: WAEmailInputTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'as 2/1/2011 18:10'!
embed
	"The embed element represents an integration point for an external (typically non-HTML) application or interactive content."
	^ self brush: WAEmbedTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'as 2/1/2011 17:04'!
embed: aBlock
	self embed with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 3/18/2007 13:26'!
figure
	"no known browser support
	
	The figure element represents a paragraph consisting of embedded content and a caption.

The first embedded content element child of the figure element, if any, is the paragraph's content.

The first legend element child of the element, if any, represents the caption of the embedded content. If there is no child legend element, then there is no caption. 

	e.g.:
	html figure: [
		html legend: 'Credit: Media Inc., 2007'.
		html image url: 'smith.jpg'; altText: 'Photo: J. Smith' ]"
	^ self tag: 'figure'! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 3/18/2007 13:25'!
figure: aBlock
	self figure with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 2/2/2011 19:44'!
figureCaption
	"The figcaption element represents a caption or legend for the rest of the contents of the figcaption element's parent figure element, if any."
	^ self tag: 'figcaption'! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 2/2/2011 19:44'!
figureCaption: aBlock
	self figureCaption with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:40'!
footer
	"The footer element represents the footer for the section it applies to. A footer typically contains information about its section such as who wrote it, links to related documents, copyright data, and the like.

	footer elements must not contain any footer, header, h1, h2, h3, h4, h5, or h6 elements, or any of the sectioning elements (such as section), as descendants.

	When used as an inline-level content container, the element represents a paragraph.

	Contact information for the section given in a footer should be marked up using the address element."
	^ self tag: 'footer '! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:40'!
footer: aBlock
	self footer with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:40'!
header
	"The header element represents the header of a section. Headers may contain more than just the section's heading \u2014 for example it would be reasonable for the header to include version history information.

	header elements must not contain any header elements, footer elements, or any sectioning elements (such as section) as descendants.

	header elements must have at least one h1, h2, h3, h4, h5, or h6 element as a descendant. "
	^ self tag: 'header '! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:40'!
header: aBlock
	self header with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 2/2/2011 19:45'!
headingGroup
	"The hgroup element represents the heading of a section. The element is used to group a set of h1-h6 elements when the heading has multiple levels, such as subheadings, alternative titles, or taglines.

	For the purposes of document summaries, outlines, and the like, the text of hgroup elements is defined to be the text of the highest ranked h1-h6 element descendant of the hgroup element, if there are any such elements, and the first such element if there are multiple elements with that rank. If there are no such elements, then the text of the hgroup element is the empty string.

	The rank of an hgroup element is the rank of the highest-ranked h1-h6 element descendant of the hgroup element, if there are any such elements, or otherwise the same as for an h1 element (the highest rank)."
	^ self tag: 'hgroup'! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 2/2/2011 19:45'!
headingGroup: aBlock
	self headingGroup with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'as 2/6/2011 22:00'!
keyGenerator
	^ self brush: WAKeyGeneratorTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 2/2/2011 19:48'!
lineBreakOpportunity
	"The wbr element represents a line break opportunity."
	^ self brush: WAOptionalBreakTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 2/2/2011 19:48'!
lineBreakOpportunity: aBlock
	self lineBreakOpportunity with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 9/25/2011 11:45'!
marked
	"no known browser support
	
	The mark element represents a run of text in one document marked or highlighted for reference purposes.

In the following snippet, a paragraph of text refers to a specific part of a code fragment.

<p>The highlighted part below is where the error lies:</p>
<pre><code>var i: Integer;
begin
   i := <mark>1.1</mark>;
end.</code></pre>

Another example of the mark element is highlighting parts of a document that are matching some search string. If someone looked at a document, and the server knew that the user was searching for the word 'kitten', then the server might return the document with one paragraph modified as follows:

<p>I also have some <mark>kitten</mark>s who are visiting me
these days. They're really cute. I think they like my garden!! Maybe I
should adopt a <mark>kitten</mark>.</p>"
	^ self tag: 'mark'! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 3/18/2007 13:29'!
marked: aBlock
	self marked with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 8/8/2007 21:59'!
menu
	^ self brush: WAMenuTag new	! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 8/8/2007 21:59'!
menu: aBlock
	self menu with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 3/28/2007 22:36'!
meter
	^ self brush: WAMeterTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 3/28/2007 22:36'!
meter: aBlock
	self meter with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'as 2/6/2011 22:00'!
monthInput
	^ self brush: WAMonthInputTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:52'!
navigation
	"The nav element represents a section of a page that links to other pages or to parts within the page: a section with navigation links.

	When used as an inline-level content container, the element represents a paragraph.

	Each nav element potentially has a heading."
	^ self tag: 'nav'! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:52'!
navigation: aBlock
	self navigation with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'as 2/6/2011 22:00'!
numberInput
	^ self brush: WANumberInputTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 9/28/2011 19:07'!
output
	^ self brush: WAOutputTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 9/28/2011 19:07'!
output: aBlock
	^ self output with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 3/28/2007 22:42'!
progress
	^ self brush: WAProgressTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 3/28/2007 22:42'!
progress: aBlock
	self progress with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'as 2/6/2011 22:00'!
rangeInput
	^ self brush: WARangeInputTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5-ruby' stamp: 'mb 9/21/2006 16:26'!
ruby
	^ self tag: 'ruby'! !

!WAHtmlCanvas methodsFor: '*seaside-html5-ruby' stamp: 'mb 9/21/2006 16:26'!
ruby: aBlock
	self ruby with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5-ruby' stamp: 'mb 9/21/2006 16:26'!
rubyParentheses
	^ self tag: 'rp'! !

!WAHtmlCanvas methodsFor: '*seaside-html5-ruby' stamp: 'mb 9/21/2006 16:26'!
rubyParentheses: aBlock
	self rubyParentheses with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5-ruby' stamp: 'pmm 9/26/2011 18:24'!
rubyText
	^ self tag: 'rt'! !

!WAHtmlCanvas methodsFor: '*seaside-html5-ruby' stamp: 'mb 9/21/2006 16:26'!
rubyText: aBlock
	self rubyText with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'as 2/6/2011 22:00'!
searchInput
	^ self brush: WASearchInputTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:41'!
section
	"The section element represents a generic document or application section. A section, in this context, is a thematic grouping of content, typically with a header, possibly with a footer."
	^ self tag: 'section '! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:41'!
section: aBlock
	self section with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:50'!
source
	^ self brush: WASourceTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 7/29/2007 10:50'!
source: aBlock
	self source with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 9/26/2011 18:21'!
summary
	"The summary element represents a summary, caption, or legend for the rest of the contents of the summary element's parent details element, if any."
	^ self tag: 'summary '! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 9/26/2011 18:21'!
summary: aBlock
	self summary with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'as 2/6/2011 22:00'!
telephoneInput
	^ self brush: WATelephoneInputTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 4/20/2007 01:25'!
time
	^ self brush: WATimeTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'pmm 4/20/2007 01:26'!
time: aBlock
	self time with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'as 2/6/2011 22:00'!
timeInput5
	^ self brush: WATimeInputTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'as 2/6/2011 22:00'!
urlInput
	^ self brush: WAUrlInputTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 3/18/2007 12:58'!
video
	^ self brush: WAVideoTag new! !

!WAHtmlCanvas methodsFor: '*seaside-html5' stamp: 'pmm 3/18/2007 12:58'!
video: aBlock
	self video with: aBlock! !

!WAHtmlCanvas methodsFor: '*seaside-html5-input' stamp: 'as 2/6/2011 22:00'!
weekInput
	^ self brush: WAWeekInputTag new! !

!WAHtmlRoot methodsFor: '*seaside-html5' stamp: 'pmm 4/20/2007 22:49'!
beHtml5
	self docType: '<!!DOCTYPE html>'! !
